==> infloat_py-0.1.1.tar.gz: infloat_py-0.1.1/README.md <==
# Infloat Python Library

[![fern shield](https://img.shields.io/badge/%F0%9F%8C%BF-Built%20with%20Fern-brightgreen)](https://buildwithfern.com?utm_source=github&utm_medium=github&utm_campaign=readme&utm_source=https%3A%2F%2Fgithub.com%2Finfloatco%2Finfloat-python-sdk)
[![pypi](https://img.shields.io/pypi/v/infloat-py)](https://pypi.python.org/pypi/infloat-py)

The Infloat Python library provides convenient access to the Infloat API from Python.

## Installation

```sh
pip install infloat-py
```

## Reference

A full reference for this library is available [here](./reference.md).

## Usage

Instantiate and use the client with the following:

```python
from Infloat import InfloatApi

client = InfloatApi(
    token="YOUR_TOKEN",
)
client.auth.login(
    email="email",
    password="password",
)
```

## Async Client

The SDK also exports an `async` client so that you can make non-blocking calls to our API.

```python
import asyncio

from Infloat import AsyncInfloatApi

client = AsyncInfloatApi(
    token="YOUR_TOKEN",
)


async def main() -> None:
    await client.auth.login(
        email="email",
        password="password",
    )


asyncio.run(main())
```

## Exception Handling

When the API returns a non-success status code (4xx or 5xx response), a subclass of the following error
will be thrown.

```python
from Infloat.core.api_error import ApiError

try:
    client.auth.login(...)
except ApiError as e:
    print(e.status_code)
    print(e.body)
```

## Advanced

### Retries

The SDK is instrumented with automatic retries with exponential backoff. A request will be retried as long
as the request is deemed retriable and the number of retry attempts has not grown larger than the configured
retry limit (default: 2).

A request is deemed retriable when any of the following HTTP status codes is returned:

- [408](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/408) (Timeout)
- [429](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/429) (Too Many Requests)
- [5XX](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/500) (Internal Server Errors)

Use the `max_retries` request option to configure this behavior.

```python
client.auth.login(..., request_options={
    "max_retries": 1
})
```

### Timeouts

The SDK defaults to a 60 second timeout. You can configure this with a timeout option at the client or request level.

```python

from Infloat import InfloatApi

client = InfloatApi(
    ...,
    timeout=20.0,
)


# Override timeout for a specific method
client.auth.login(..., request_options={
    "timeout_in_seconds": 1
})
```

### Custom Client

You can override the `httpx` client to customize it for your use-case. Some common use-cases include support for proxies
and transports.
```python
import httpx
from Infloat import InfloatApi

client = InfloatApi(
    ...,
    httpx_client=httpx.Client(
        proxies="http://my.test.proxy.example.com",
        transport=httpx.HTTPTransport(local_address="0.0.0.0"),
    ),
)
```

## Contributing

While we value open-source contributions to this SDK, this library is generated programmatically.
Additions made directly to this library would have to be moved over to our generation code,
otherwise they would be overwritten upon the next generated release. Feel free to open a PR as
a proof of concept, but know that we will not be able to merge it as-is. We suggest opening
an issue first to discuss with us!

On the other hand, contributions to the README are always very welcome!

==> infloat_py-0.2.2.tar.gz: infloat_py-0.2.2/README.md <==
# Infloat Python Library

[![fern shield](https://img.shields.io/badge/%F0%9F%8C%BF-Built%20with%20Fern-brightgreen)](https://buildwithfern.com?utm_source=github&utm_medium=github&utm_campaign=readme&utm_source=https%3A%2F%2Fgithub.com%2Finfloatco%2Finfloat-python-sdk)
[![pypi](https://img.shields.io/pypi/v/infloat-py)](https://pypi.python.org/pypi/infloat-py)

The Infloat Python library provides convenient access to the Infloat API from Python.

## Installation

```sh
pip install infloat-py
```

## Reference

A full reference for this library is available [here](./reference.md).

## Usage

Instantiate and use the client with the following:

```python
from Infloat import InfloatApi

client = InfloatApi(
    base_url="https://yourhost.com/path/to/api",
)
client.register_user_auth_register_post(
    name="name",
    email="email",
    password="password",
)
```

## Async Client

The SDK also exports an `async` client so that you can make non-blocking calls to our API.

```python
import asyncio

from Infloat import AsyncInfloatApi

client = AsyncInfloatApi(
    base_url="https://yourhost.com/path/to/api",
)


async def main() -> None:
    await client.register_user_auth_register_post(
        name="name",
        email="email",
        password="password",
    )


asyncio.run(main())
```

## Exception Handling

When the API returns a non-success status code (4xx or 5xx response), a subclass of the following error
will be thrown.

```python
from Infloat.core.api_error import ApiError

try:
    client.register_user_auth_register_post(...)
except ApiError as e:
    print(e.status_code)
    print(e.body)
```

## Advanced

### Retries

The SDK is instrumented with automatic retries with exponential backoff. A request will be retried as long
as the request is deemed retriable and the number of retry attempts has not grown larger than the configured
retry limit (default: 2).

A request is deemed retriable when any of the following HTTP status codes is returned:

- [408](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/408) (Timeout)
- [429](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/429) (Too Many Requests)
- [5XX](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/500) (Internal Server Errors)

Use the `max_retries` request option to configure this behavior.

```python
client.register_user_auth_register_post(..., request_options={
    "max_retries": 1
})
```

### Timeouts

The SDK defaults to a 60 second timeout. You can configure this with a timeout option at the client or request level.

```python

from Infloat import InfloatApi

client = InfloatApi(
    ...,
    timeout=20.0,
)


# Override timeout for a specific method
client.register_user_auth_register_post(..., request_options={
    "timeout_in_seconds": 1
})
```

### Custom Client

You can override the `httpx` client to customize it for your use-case. Some common use-cases include support for proxies
and transports.
```python
import httpx
from Infloat import InfloatApi

client = InfloatApi(
    ...,
    httpx_client=httpx.Client(
        proxies="http://my.test.proxy.example.com",
        transport=httpx.HTTPTransport(local_address="0.0.0.0"),
    ),
)
```

## Contributing

While we value open-source contributions to this SDK, this library is generated programmatically.
Additions made directly to this library would have to be moved over to our generation code,
otherwise they would be overwritten upon the next generated release. Feel free to open a PR as
a proof of concept, but know that we will not be able to merge it as-is. We suggest opening
an issue first to discuss with us!

On the other hand, contributions to the README are always very welcome!
